@@ -118,7 +118,7 @@ class LinuxDevice(object):
     '''
     A base class for common linux devices.
     '''
-    release = '1.1.26'
+    release = '1.1.27'
 
     LOG_EMERG = 0   # not used
     LOG_ALERT = 1   # not used
@@ -497,7 +497,7 @@ class LinuxDevice(object):
         self["log_color"], with the local time if self['log_time'] is True,
         the log looks like::
 
-            [ regazara ][2017-05-16 16:02:07]: ssh login succeed.
+            [2017-05-16 16:02:07][ regazara ]: ssh login succeed.
 
         @ message: The log text.
 
@@ -516,16 +516,13 @@ class LinuxDevice(object):
         if level > log_level or (not kwargs.get("with_log", True)):
             return
 
-        name_color = color_dict.get(self['log_color'], '\033[00m')
-        thread_name = threading.current_thread().name
-        name = self["name"] and self["name"] or self.name
-
-        if self['log_time']:
-            now = time.strftime('%Y%m%d %H:%M:%S',time.localtime(time.time()))
-            #l += "[%s][%s]" %(now, thread_name)
-            l = "[%s][%s%s\033[0m]" %(now, name_color, name)
-        else:
-            l = "[%s%s\033[0m]" %(name_color, name)
+        name_color = color_dict.get(self['log_color'], None)
+        now = time.strftime('%Y%m%d %H:%M:%S',time.localtime(time.time()))
+        l = self['log_time'] and "[%s]" %(now) or ""
+        #l += "[%s][%s]" %(now, threading.current_thread().name)
+        l += "[%s%s%s]" %(name_color and name_color or "",
+                self["name"] and self["name"] or self.name,
+                name_color and "\033[0m" or "")
 
         f = StringIO(message)
         for i in f.readlines():
